@@ -78,6 +78,7 @@ CREDITS = dict(
         'Alex Carvalho (Brazilian Portuguese)',
         'Juliano de Souza Camargo (Brazilian Portuguese)',
         'Giovanne Menicheli (Brazilian Portuguese)',
+        'Fúlvio Alves (Brazilian Portuguese)',
         'twlvnn (Bulgarian)',
         'Roger VC (Catalan)',
         'Dingzhong Chen (Simplified Chinese)',
@@ -102,6 +103,7 @@ CREDITS = dict(
         'Liliana Marie Prikler (German)',
         'Tim (German)',
         'Sear Gasor (German)',
+        'Vortex Acherontic (German)',
         'Scrambled777 (Hindi)',
         'Milo Ivir (Croatian)',
         'Alifiyan Rosyidi (Indonesian)',
@@ -111,6 +113,7 @@ CREDITS = dict(
         'dedocc (Italian)',
         'Davide Mora (Italian)',
         'Lili Kurek (Polish)',
+        'Aleksander Warzyniak (Polish)',
         'ssantos (Portuguese)',
         'Ademario Cunha (Portuguese)',
         'SpiralPack 527 (Portuguese)',
@@ -122,6 +125,7 @@ CREDITS = dict(
         'Óscar Fernández Díaz (Spanish)',
         'gallegonovato (Spanish)',
         'Jesper (Swedish)',
+        'PaneradFisk (Swedish)',
         'Ege Çelikçi (Turkish)',
         'Sabri Ünal (Turkish)',
         'Volkan Yıldırım (Turkish)',
@@ -525,14 +529,26 @@ available in your region/language."""))
         # Override release notes
         dialog.set_release_notes("""
             <ul>
-                <li>[Preferences] Servers settings: Added language indicator</li>
-                <li>[Reader] Fixed keyboard navigation bugs after changing reading mode</li>
-                <li>[Reader] Webtoon pager: Extended scrollable zone to all viewport</li>
-                <li>[Reader] Fixed unwanted display/hiding of cursor during keyboard navigation</li>
-                <li>[Servers] MangaReader: Added ES/ES_LA/PT/pt_BR languages support</li>
-                <li>[Servers] MangaReader (multi): Improved search by finally taking into account language</li>
-                <li>[Servers] Read Comic Online (EN): Update</li>
-                <li>[L10n] Updated Croatian and German translations</li>
+                <li>[Reader] Paused pages animations when obscured</li>
+                <li>[Servers] Anteiku Scans (FR): Update</li>
+                <li>[Servers] Asura Scans For Free (EN): Update</li>
+                <li>[Servers] ED Scanlation (FR): Update</li>
+                <li>[Servers] EZmanga (EN): Update</li>
+                <li>[Servers] Kewn Scans (EN): Update</li>
+                <li>[Servers] MonkeyUser (EN): Update</li>
+                <li>[Servers] Pepper&amp;Carrot: Update</li>
+                <li>[Servers] Starbound Scans (FR): Update</li>
+                <li>[Servers] Terco Scans (ES): Update</li>
+                <li>[Servers] Webtoon Hatti (TR): Update</li>
+                <li>[Servers] Rukav Inari (ES): Disabled</li>
+                <li>[Servers] MangaWeebs (EN): Disabled</li>
+                <li>[Servers] LSComic (EN): Disabled</li>
+                <li>[Servers] Hunlight Scans (EN): Disabled</li>
+                <li>[Servers] Mode Scanlator (pt_BR): Disabled</li>
+                <li>[Servers] Best Manga (RU): Disabled</li>
+                <li>[Servers] Atikrost (TR): Disabled</li>
+                <li>[Servers] Perf Scan (FR): Disabled</li>
+                <li>[L10n] Updated Bulgarian, German and Polish translations</li>
             </ul>
             <p>Happy reading.</p>
         """)
